@@ -65,16 +65,22 @@ class WirelessDeviceTrayPrivate
 
 TQStringList WirelessDeviceTray::getToolTipText()
 {
-	TDENetworkDevice* dev = dynamic_cast<TDENetworkDevice*>(hwdevices->findByUniqueID(d->dev));
-
 	TQStringList tooltip = DeviceTrayComponent::getToolTipText();
 
-	TDENetworkConnectionManager* deviceConnMan = dev->connectionManager();
-	TDENetworkWiFiAPInfo * ap = deviceConnMan->findAccessPointByBSSID(deviceConnMan->deviceInformation().wiFiInfo.activeAccessPointBSSID);
-	if (ap) {
-		tooltip.append(i18n("Network: %1").arg(ap->friendlySSID()));
-		int strength = (ap->signalQuality*100.0);
-		tooltip.append(i18n("Signal Strength: %1%").arg(strength));
+	TDENetworkDevice* dev = dynamic_cast<TDENetworkDevice*>(hwdevices->findByUniqueID(d->dev));
+	if (dev)
+	{
+		TDENetworkConnectionManager* deviceConnMan = dev->connectionManager();
+		if (deviceConnMan)
+		{
+			TDENetworkWiFiAPInfo * ap = deviceConnMan->findAccessPointByBSSID(deviceConnMan->deviceInformation().wiFiInfo.activeAccessPointBSSID);
+			if (ap)
+			{
+				tooltip.append(i18n("Network: %1").arg(ap->friendlySSID()));
+				int strength = (ap->signalQuality*100.0);
+				tooltip.append(i18n("Signal Strength: %1%").arg(strength));
+			}
+		}
 	}
 
 	return tooltip;
@@ -88,6 +94,10 @@ void WirelessDeviceTray::newConnection()
 void WirelessDeviceTray::newConnection(int id)
 {
 	TDEGlobalNetworkManager* nm = TDEGlobal::networkManager();
+	if (!nm)
+	{
+		return;
+	}
 
 	// create a new wireless connection
 	TDENetworkConnection* conn = new TDEWiFiConnection();
@@ -154,12 +164,16 @@ void WirelessDeviceTray::addWirelessNetworks(TDEPopupMenu* menu)
 	TQValueList<TDEWiFiConnection*> conns = WirelessManager::getWirelessConnections();
 
 	// get the currently active connection
-	TDENetworkConnectionManager* deviceConnMan = dev->connectionManager();
+	TDENetworkConnectionManager* deviceConnMan = (dev ? dev->connectionManager() : NULL);
 	TDENetworkConnection* active_conn = NULL;
-	TDENetworkDeviceInformation devInfo = deviceConnMan->deviceStatus();
-	if ((!(devInfo.statusFlags & TDENetworkConnectionStatus::Disconnected))
-		&& (!(devInfo.statusFlags & TDENetworkConnectionStatus::Invalid))) {
-		active_conn = nm->findConnectionByUUID(devInfo.activeConnectionUUID);
+	if (nm && deviceConnMan)
+	{
+		TDENetworkDeviceInformation devInfo = deviceConnMan->deviceStatus();
+		if ((!(devInfo.statusFlags & TDENetworkConnectionStatus::Disconnected))
+			&& (!(devInfo.statusFlags & TDENetworkConnectionStatus::Invalid)))
+		{
+			active_conn = nm->findConnectionByUUID(devInfo.activeConnectionUUID);
+		}
 	}
 
 	// add all wireless connections in range
@@ -258,6 +272,10 @@ void WirelessDeviceTray::addWirelessNetworks(TDEPopupMenu* menu)
 void WirelessDeviceTray::addMenuItems(TDEPopupMenu* menu)
 {
 	TDENetworkDevice* dev = dynamic_cast<TDENetworkDevice*>(hwdevices->findByUniqueID(d->dev));
+	if (!dev)
+	{
+		return;
+	}
 
 	// get the currently active connection
 	TDEGlobalNetworkManager* nm = TDEGlobal::networkManager();
@@ -267,7 +285,8 @@ void WirelessDeviceTray::addMenuItems(TDEPopupMenu* menu)
 	menu->insertItem (subhead, -1, -1);
 
 	TDENetworkConnectionManager* deviceConnMan = dev->connectionManager();
-	if (!deviceConnMan->deviceInformation().managed) {
+	if (!nm || !deviceConnMan || !deviceConnMan->deviceInformation().managed)
+	{
 		// device is not managed by NM -> do not show any connections
 		subhead = new Subhead(menu, "subhead2", i18n("Not managed"), SmallIcon("no", TQIconSet::Automatic));
 		menu->insertItem(subhead, -1, -1);
@@ -312,7 +331,12 @@ void WirelessDeviceTray::slotUpdateDeviceState(TDENetworkConnectionStatus::TDENe
 {
 	TDENetworkDevice* dev = dynamic_cast<TDENetworkDevice*>(hwdevices->findByUniqueID(d->dev));
 
-	if (dev->deviceNode() != deviceNode) {
+	if (!dev)
+	{
+		return;
+	}
+	if (dev->deviceNode() != deviceNode)
+	{
 		kdDebug() << k_funcinfo << "WARNING: Got networkDeviceStateChanged signal for interface '" << deviceNode << "', but my interface is '" << dev->deviceNode() << "'!  Ignoring...";
 		return;
 	}
@@ -326,24 +350,33 @@ void WirelessDeviceTray::slotUpdateDeviceState(TDENetworkConnectionStatus::TDENe
 	if (newState == TDENetworkConnectionStatus::Connected) {
 		// trigger an update of the connections seen bssids property
 		TDENetworkConnectionManager* deviceConnMan = dev->connectionManager();
-		TDENetworkWiFiAPInfo * ap = deviceConnMan->findAccessPointByBSSID(deviceConnMan->deviceInformation().wiFiInfo.activeAccessPointBSSID);
-		if (ap) {
-			int strength = (ap->signalQuality*100.0);
+		if (deviceConnMan)
+		{
+			TDENetworkWiFiAPInfo * ap = deviceConnMan->findAccessPointByBSSID(deviceConnMan->deviceInformation().wiFiInfo.activeAccessPointBSSID);
+			if (ap)
+			{
+				int strength = (ap->signalQuality*100.0);
 
-			if (strength > 80) {
-				setPixmapForStates(newState, "nm_signal_100");
-			}
-			else if (strength > 55) {
-				setPixmapForStates(newState, "nm_signal_75");
-			}
-			else if (strength > 30) {
-				setPixmapForStates(newState, "nm_signal_50");
-			}
-			else if (strength > 5) {
-				setPixmapForStates(newState, "nm_signal_25");
-			}
-			else {
-				setPixmapForStates(newState, "nm_signal_00");
+				if (strength > 80)
+				{
+					setPixmapForStates(newState, "nm_signal_100");
+				}
+				else if (strength > 55)
+				{
+					setPixmapForStates(newState, "nm_signal_75");
+				}
+				else if (strength > 30)
+				{
+					setPixmapForStates(newState, "nm_signal_50");
+				}
+				else if (strength > 5)
+				{
+					setPixmapForStates(newState, "nm_signal_25");
+				}
+				else
+				{
+					setPixmapForStates(newState, "nm_signal_00");
+				}
 			}
 		}
 	}
@@ -361,25 +394,34 @@ void WirelessDeviceTray::slotCheckActiveAccessPoint()
 
 	// get the currently active connection
 	TDEGlobalNetworkManager* nm = TDEGlobal::networkManager();
-	TDENetworkConnectionManager* deviceConnMan = dev->connectionManager();
+	TDENetworkConnectionManager* deviceConnMan = (dev ? dev->connectionManager() : NULL);
 	TDENetworkConnection* active_conn = NULL;
 
-	TDENetworkDeviceInformation devInfo = deviceConnMan->deviceStatus();
-	if ((!(devInfo.statusFlags & TDENetworkConnectionStatus::Disconnected))
-		&& (!(devInfo.statusFlags & TDENetworkConnectionStatus::Invalid))) {
-		active_conn = nm->findConnectionByUUID(devInfo.activeConnectionUUID);
-	}
+	if (nm && deviceConnMan)
+	{
+		TDENetworkDeviceInformation devInfo = deviceConnMan->deviceStatus();
+		if ((!(devInfo.statusFlags & TDENetworkConnectionStatus::Disconnected))
+			&& (!(devInfo.statusFlags & TDENetworkConnectionStatus::Invalid)))
+		{
+			active_conn = nm->findConnectionByUUID(devInfo.activeConnectionUUID);
+		}
 
-	if (active_conn && devInfo.statusFlags == TDENetworkConnectionStatus::Connected) {
-		TDENetworkDeviceInformation devInfo = deviceConnMan->deviceInformation();
-		TDENetworkWiFiAPInfo * activeap = deviceConnMan->findAccessPointByBSSID(devInfo.wiFiInfo.activeAccessPointBSSID);
-		if ( activeap != d->activeAccessPoint) {
-			d->activeAccessPoint = activeap;
-			if ( d->activeAccessPoint ) {
-				TDEWiFiConnection* wireless = dynamic_cast<TDEWiFiConnection*>(active_conn);
-				if (wireless) {
-					if (!(wireless->heardBSSIDs.contains(d->activeAccessPoint->BSSID))) {
-						wireless->heardBSSIDs.append(d->activeAccessPoint->BSSID);
+		if (active_conn && devInfo.statusFlags == TDENetworkConnectionStatus::Connected)
+		{
+			TDENetworkDeviceInformation devInfo = deviceConnMan->deviceInformation();
+			TDENetworkWiFiAPInfo * activeap = deviceConnMan->findAccessPointByBSSID(devInfo.wiFiInfo.activeAccessPointBSSID);
+			if ( activeap != d->activeAccessPoint)
+			{
+				d->activeAccessPoint = activeap;
+				if ( d->activeAccessPoint )
+				{
+					TDEWiFiConnection* wireless = dynamic_cast<TDEWiFiConnection*>(active_conn);
+					if (wireless)
+					{
+						if (!(wireless->heardBSSIDs.contains(d->activeAccessPoint->BSSID)))
+						{
+							wireless->heardBSSIDs.append(d->activeAccessPoint->BSSID);
+						}
 					}
 				}
 			}
@@ -390,30 +432,43 @@ void WirelessDeviceTray::slotCheckActiveAccessPoint()
 void WirelessDeviceTray::apPropertyChanged(TDEMACAddress BSSID, TDENetworkAPEventType::TDENetworkAPEventType event)
 {
 	TDENetworkDevice* dev = dynamic_cast<TDENetworkDevice*>(hwdevices->findByUniqueID(d->dev));
+	if (!dev)
+	{
+		return;
+	}
 
 	if (event == TDENetworkAPEventType::SignalStrengthChanged) {
 		TDENetworkConnectionManager* deviceConnMan = dev->connectionManager();
-		TDENetworkWiFiAPInfo * ap = deviceConnMan->findAccessPointByBSSID(BSSID);
-		if (ap) {
-			TQ_UINT32 strength = (ap->signalQuality*100.0);
-			kdDebug() << k_funcinfo << strength << endl;
-			TDENetworkConnectionStatus::TDENetworkConnectionStatus state = deviceConnMan->deviceInformation().statusFlags;
-			if (strength > 80) {
-				setPixmapForStates(state, "nm_signal_100");
+		if (deviceConnMan)
+		{
+			TDENetworkWiFiAPInfo * ap = deviceConnMan->findAccessPointByBSSID(BSSID);
+			if (ap)
+			{
+				TQ_UINT32 strength = (ap->signalQuality*100.0);
+				kdDebug() << k_funcinfo << strength << endl;
+				TDENetworkConnectionStatus::TDENetworkConnectionStatus state = deviceConnMan->deviceInformation().statusFlags;
+				if (strength > 80)
+				{
+					setPixmapForStates(state, "nm_signal_100");
+				}
+				else if (strength > 55)
+				{
+					setPixmapForStates(state, "nm_signal_75");
+				}
+				else if (strength > 30)
+				{
+					setPixmapForStates(state, "nm_signal_50");
+				}
+				else if (strength > 5)
+				{
+					setPixmapForStates(state, "nm_signal_25");
+				}
+				else
+				{
+					setPixmapForStates(state, "nm_signal_00");
+				}
+				TQTimer::singleShot(0, this, TQT_SLOT(sendUpdateUI()));
 			}
-			else if (strength > 55) {
-				setPixmapForStates(state, "nm_signal_75");
-			}
-			else if (strength > 30) {
-				setPixmapForStates(state, "nm_signal_50");
-			}
-			else if (strength > 5) {
-				setPixmapForStates(state, "nm_signal_25");
-			}
-			else {
-				setPixmapForStates(state, "nm_signal_00");
-			}
-			TQTimer::singleShot(0, this, TQT_SLOT(sendUpdateUI()));
 		}
 	}
 }
@@ -428,38 +483,29 @@ void WirelessDeviceTray::slotAccessPointRemoved(TDEMACAddress)
 	KNotifyClient::event( tray()->winId(), "tdenm-nm-network-gone", i18n("TDENetworkManager Wireless Network Disappeared") );
 }
 
-void WirelessDeviceTray::tdeHardwareEventHandler(TDEHardwareEvent::TDEHardwareEvent event, TQString)
-{
-	if (event == TDEHardwareEvent::HardwareListModified) {
-		TDENetworkDevice* dev = dynamic_cast<TDENetworkDevice*>(hwdevices->findByUniqueID(d->dev));
-		TDENetworkConnectionManager* deviceConnMan = (dev)?dev->connectionManager():NULL;
-
-		// get notified when the device state changes
-		connect(deviceConnMan, TQT_SIGNAL(networkDeviceStateChanged(TDENetworkConnectionStatus::TDENetworkConnectionStatus, TDENetworkConnectionStatus::TDENetworkConnectionStatus, TQString)), this, TQT_SLOT(slotUpdateDeviceState(TDENetworkConnectionStatus::TDENetworkConnectionStatus, TDENetworkConnectionStatus::TDENetworkConnectionStatus, TQString)));
-	
-		// get notified of all AP changes
-		connect(deviceConnMan, TQT_SIGNAL(accessPointStatusChanged(TDEMACAddress, TDENetworkAPEventType::TDENetworkAPEventType)), this, TQT_SLOT(tdeAccessPointStatusChangedHandler(TDEMACAddress, TDENetworkAPEventType::TDENetworkAPEventType)));
-
-		// force status update to ensure correct icon is shown on startup
-		if ((dev) && (deviceConnMan)) {
-			slotUpdateDeviceState(deviceConnMan->deviceInformation().statusFlags, TDENetworkConnectionStatus::Invalid, dev->deviceNode());
-		}
-	}
-}
-
 void WirelessDeviceTray::tdeAccessPointStatusChangedHandler(TDEMACAddress BSSID, TDENetworkAPEventType::TDENetworkAPEventType event) {
 	TDENetworkDevice* dev = dynamic_cast<TDENetworkDevice*>(hwdevices->findByUniqueID(d->dev));
+	if (!dev)
+	{
+		return;
+	}
+
 	TDENetworkConnectionManager* deviceConnMan = dev->connectionManager();
 
 	if (event == TDENetworkAPEventType::Discovered) {
-		TDENetworkWiFiAPInfo* apinfo = deviceConnMan->findAccessPointByBSSID(BSSID);
-		slotAccessPointAdded(apinfo);
+		if (deviceConnMan)
+		{
+			TDENetworkWiFiAPInfo* apinfo = deviceConnMan->findAccessPointByBSSID(BSSID);
+			slotAccessPointAdded(apinfo);
+		}
 	}
 	else if (event == TDENetworkAPEventType::Lost) {
 		slotAccessPointRemoved(BSSID);
 	}
 	else if (event == TDENetworkAPEventType::SignalStrengthChanged) {
-		if (deviceConnMan->deviceInformation().wiFiInfo.activeAccessPointBSSID == BSSID) {
+		if (deviceConnMan &&
+		    deviceConnMan->deviceInformation().wiFiInfo.activeAccessPointBSSID == BSSID)
+		{
 			apPropertyChanged(BSSID, event);
 		}
 	}
@@ -487,11 +533,20 @@ WirelessDeviceTray::WirelessDeviceTray (TQString dev, KSystemTray * parent, cons
 	setPixmapForState(TDENetworkConnectionStatus::Disconnected, "wireless");
 	setPixmapForState(TDENetworkConnectionStatus::Connected, "nm_signal_50");
 
-	// Listen for hardware change events
-	connect(hwdevices, TQT_SIGNAL(hardwareEvent(TDEHardwareEvent::TDEHardwareEvent, TQString)), this, TQT_SLOT(tdeHardwareEventHandler(TDEHardwareEvent::TDEHardwareEvent, TQString)));
+	// initial hardware information update
+	TDENetworkDevice* netdev = dynamic_cast<TDENetworkDevice*>(hwdevices->findByUniqueID(d->dev));
+	TDENetworkConnectionManager* deviceConnMan = (netdev)?netdev->connectionManager():NULL;
 
-	// Trigger an initial hardware information update
-	tdeHardwareEventHandler(TDEHardwareEvent::HardwareListModified, TQString::null);
+	// get notified when the device state changes
+	connect(deviceConnMan, TQT_SIGNAL(networkDeviceStateChanged(TDENetworkConnectionStatus::TDENetworkConnectionStatus, TDENetworkConnectionStatus::TDENetworkConnectionStatus, TQString)), this, TQT_SLOT(slotUpdateDeviceState(TDENetworkConnectionStatus::TDENetworkConnectionStatus, TDENetworkConnectionStatus::TDENetworkConnectionStatus, TQString)));
+
+	// get notified of all AP changes
+	connect(deviceConnMan, TQT_SIGNAL(accessPointStatusChanged(TDEMACAddress, TDENetworkAPEventType::TDENetworkAPEventType)), this, TQT_SLOT(tdeAccessPointStatusChangedHandler(TDEMACAddress, TDENetworkAPEventType::TDENetworkAPEventType)));
+
+	// force status update to ensure correct icon is shown on startup
+	if ((netdev) && (deviceConnMan)) {
+		slotUpdateDeviceState(deviceConnMan->deviceInformation().statusFlags, TDENetworkConnectionStatus::Invalid, netdev->deviceNode());
+	}
 }
 
 WirelessDeviceTray::~WirelessDeviceTray ()
