@@ -44,6 +44,10 @@ using namespace ConnectionSettings;
 void VPNTrayComponent::slotShowNewConnectionDialog()
 {
 	TDEGlobalNetworkManager* nm = TDEGlobal::networkManager();
+	if (!nm)
+	{
+		return;
+	}
 
 	// create a new VPN connection
 	TDEVPNConnection* conn = new TDEVPNConnection();
@@ -63,6 +67,10 @@ void VPNTrayComponent::addMenuItems(TDEPopupMenu* menu)
 
 	// Get all active connections
 	TDEGlobalNetworkManager* nm = TDEGlobal::networkManager();
+	if (!nm)
+	{
+		return;
+	}
 
 	if (tdenetworkmanager_editor_dialog_count == 0) nm->loadConnectionInformation();
 
