@@ -588,7 +588,7 @@ TDENetworkSettingsMap OpenVPNAuthentication::getPasswords()
 {
 	TQMap<TQString, TQString> pwds;
 	if ((_connectionType == OpenVPNConnectionType::PASSWORD) || (_connectionType == OpenVPNConnectionType::X509USERPASS))
-		pwds.insert("password", TQString(_openvpnAuth->editUserPassword->password()));
+		pwds.insert("password", _openvpnAuth->editUserPassword->password());
 	else
 		pwds.insert("no-secret", TQString("true"));
 
