@@ -390,7 +390,7 @@ VPNCAuthentication::~VPNCAuthentication()
 TDENetworkSettingsMap VPNCAuthentication::getPasswords()
 {
 	TDENetworkSettingsMap pwds;
-	pwds.insert("Xauth password", TQString(_vpncAuth->editUserPassword->password()));
+	pwds.insert("Xauth password", _vpncAuth->editUserPassword->password());
 	if (_vpncAuth->chkObfusticated->isChecked()) {
 		// Decrypt the obfusticated password with /usr/lib/vpnc/cisco-decrypt
 		string decryptcommand="/usr/lib/vpnc/cisco-decrypt ";
@@ -398,7 +398,7 @@ TDENetworkSettingsMap VPNCAuthentication::getPasswords()
 		char decrypted_result[2048];
 		int i;
 
-		decryptcommand.append(TQString::fromUtf8(_vpncAuth->editGroupPassword->password()).local8Bit());
+		decryptcommand.append(_vpncAuth->editGroupPassword->password().local8Bit());
 		printf("Group password decrypt command: %s\n", decryptcommand.c_str());
 		if ((pipe_decrypt = popen(decryptcommand.c_str(), "r")) == NULL)
 		{
@@ -420,7 +420,7 @@ TDENetworkSettingsMap VPNCAuthentication::getPasswords()
 		}
 	}
 	else {
-		pwds.insert("IPSec secret", TQString(_vpncAuth->editGroupPassword->password()));
+		pwds.insert("IPSec secret", _vpncAuth->editGroupPassword->password());
 	}
 	return pwds;
 }
